@@ -5,10 +5,10 @@ import (
 	"os"
 )
 
-func errorf(format string, args ...interface{}) {
+func errorf(format string, args ...any) {
 	fmt.Fprintf(os.Stderr, "error: "+format+"\n", args...)
 }
 
-func infof(format string, args ...interface{}) {
+func infof(format string, args ...any) {
 	fmt.Fprintf(os.Stderr, format+"\n", args...)
 }
